@@ -30,7 +30,7 @@ sub properties {
     my($self) = @_;
 
     my $property = Net::Amazon::Property::factory(
-        xmlref => $self->{xmlref}->{Details});
+        xmlref => $self->{xmlref}->{Details}->[0]);
 
     return ($property);
 }
